import React from "react";
import { Box, Button, Center, Container, DarkMode, Flex, HStack, IconButton, Image, Link, useDisclosure, VStack, } from "@chakra-ui/react";
import { HamburgerIcon, CloseIcon } from "@chakra-ui/icons";
import { useWallet } from "@solana/wallet-adapter-react";
import { TwitterLink } from "./TwitterLink";
import { WalletModalButton } from "./WalletModalButton";
import { route, routes } from "../utils/routes";
const NavLink = ({ href, children }) => (React.createElement(Link, { px: 2, py: 1, href: href, fontSize: "sm" }, children));
export const Header = () => {
    const Links = [
        { link: "Launchpad", href: route(routes.launchpad) },
        { link: "Bounties", href: route(routes.bounties) },
    ];
    const { disconnect, connected } = useWallet();
    const { isOpen, onOpen, onClose } = useDisclosure();
    return (React.createElement(React.Fragment, null,
        React.createElement(Box, { zIndex: 100, color: "white", bg: "black.300", w: "full" },
            React.createElement(Center, { w: "full", height: "56px", alignItems: "center" },
                React.createElement(Container, { maxW: "container.lg", w: "full", display: "flex", justifyContent: "space-between" },
                    React.createElement(IconButton, { size: "md", bg: "black.300", icon: isOpen ? React.createElement(CloseIcon, null) : React.createElement(HamburgerIcon, null), "aria-label": "Open Menu", display: { md: "none" }, _active: {
                            bg: "black.300",
                        }, _hover: {
                            bg: "black.300",
                        }, onClick: isOpen ? onClose : onOpen }),
                    React.createElement(HStack, { spacing: 8, alignItems: "center" },
                        React.createElement(Link, { href: route(routes.launchpad) },
                            React.createElement(Image, { alt: "Strata Launchpad", src: "/logo-launchpad.svg" })),
                        React.createElement(HStack, { as: "nav", spacing: 4, display: { base: "none", md: "flex" } }, Links.map((link) => (React.createElement(NavLink, { key: link.link, href: link.href }, link.link))))),
                    React.createElement(HStack, { align: "center", justify: ["center", "space-between", "flex-end", "flex-end"], direction: ["column", "row", "row", "row"], pt: "0" },
                        React.createElement(Flex, { justify: "center", align: "center", display: { base: "none", md: "flex" } },
                            React.createElement(TwitterLink, null),
                            connected && (React.createElement(Button, { size: "sm", _hover: { backgroundColor: "black.500" }, variant: "ghost", onClick: () => disconnect() }, "Disconnect")),
                            React.createElement(DarkMode, null,
                                React.createElement(WalletModalButton, null))),
                        React.createElement(Flex, { justify: "center", display: { base: "flex", md: "none" } },
                            React.createElement(DarkMode, null,
                                React.createElement(WalletModalButton, { size: "sm" })))))),
            isOpen ? (React.createElement(Box, { pb: 4, display: { md: "none" } },
                React.createElement(VStack, { as: "nav", spacing: 4 }, Links.map((link) => (React.createElement(NavLink, { key: link.link, href: link.href }, link.link)))))) : null)));
};
//# sourceMappingURL=Header.js.map