import { Button, ButtonGroup, Icon, IconButton, Menu, MenuButton, MenuItemOption, MenuList, MenuOptionGroup, useColorModeValue, } from "@chakra-ui/react";
import { WalletAdapterNetwork } from "@solana/wallet-adapter-base";
import { useWallet } from "@solana/wallet-adapter-react";
import { useWalletModal } from "@solana/wallet-adapter-react-ui";
import { useEndpoint, truncatePubkey } from "@strata-foundation/react";
import React, { useCallback } from "react";
import { BsChevronDown, BsFillPersonFill } from "react-icons/bs";
export const WalletModalButton = ({ children = "Select Wallet", onClick, ...props }) => {
    const { connected, publicKey } = useWallet();
    const { visible, setVisible } = useWalletModal();
    const handleClick = useCallback((event) => {
        if (onClick)
            onClick(event);
        if (!event.defaultPrevented)
            setVisible(!visible);
    }, [onClick, visible, setVisible]);
    const { cluster, setClusterOrEndpoint } = useEndpoint();
    return (React.createElement(ButtonGroup, { marginTop: "auto", colorScheme: "primary", color: useColorModeValue("black", "white"), variant: "outline", spacing: "6", isAttached: true, size: props.size },
        React.createElement(Button, { color: useColorModeValue("black", "white"), borderColor: "primary.500", ...props, leftIcon: React.createElement(Icon, { w: "16px", h: "16px", as: BsFillPersonFill }), onClick: handleClick, _hover: { backgroundColor: "orange.500" } }, connected ? truncatePubkey(publicKey) : children),
        React.createElement(Menu, { isLazy: true },
            React.createElement(MenuButton, { as: IconButton, color: useColorModeValue("black", "white"), borderColor: "primary.500", borderLeft: "none", "aria-label": "Network", icon: React.createElement(Icon, { as: BsChevronDown }) }),
            React.createElement(MenuList, { backgroundColor: "black.300", borderColor: "black.500" },
                React.createElement(MenuOptionGroup, { title: "Network", type: "radio", onChange: (e) => setClusterOrEndpoint(e), value: cluster },
                    React.createElement(MenuItemOption, { value: WalletAdapterNetwork.Mainnet, _focus: { backgroundColor: "primary.300" }, _hover: { backgroundColor: "primary.500" } }, "Mainnet"),
                    React.createElement(MenuItemOption, { _focus: { backgroundColor: "primary.300" }, _hover: { backgroundColor: "primary.500" }, value: WalletAdapterNetwork.Devnet }, "Devnet"),
                    React.createElement(MenuItemOption, { _focus: { backgroundColor: "primary.300" }, _hover: { backgroundColor: "primary.500" }, value: "localnet" }, "Localnet"))))));
};
//# sourceMappingURL=WalletModalButton.js.map