import React from "react";
import { HStack, Text, Spinner } from "@chakra-ui/react";
import { Creator, usePublicKey, useTokenBondingFromMint, useTokenMetadata } from "@strata-foundation/react";
const onCreatorClick = (c, t, tokenRef, handle) => {
    window.open(tokenRef
        ? `https://wum.bo/app/profile/view/${tokenRef.mint}`
        : handle
            ? `https://twitter.com/${handle}`
            : `https://explorer.solana.com/address/${c.toBase58()}`, "_blank");
};
export const InfoItem = ({ name, creator, loading }) => {
    return (React.createElement(HStack, { spacing: 2 },
        React.createElement(Text, { fontWeight: 800, color: "gray.700" },
            name,
            ":",
            " "),
        " ",
        loading ? (React.createElement(Spinner, { size: "xs" })) : creator ? (React.createElement(Creator, { creator: creator, onClick: onCreatorClick })) : "None"));
};
export const AuthorityAndTokenInfo = ({ mintKey }) => {
    const { info: tokenBonding, loading } = useTokenBondingFromMint(mintKey);
    const { metadata, loading: loadingMeta } = useTokenMetadata(mintKey);
    const updateAuthority = usePublicKey(metadata?.updateAuthority);
    return (React.createElement(HStack, { justify: "center", gap: 1, flexWrap: "wrap", fontSize: "14px", spacing: 4 },
        React.createElement(InfoItem, { creator: updateAuthority, loading: loading, name: "Requester" }),
        React.createElement(InfoItem, { creator: tokenBonding?.reserveAuthority, loading: loading, name: "Approver" })));
};
//# sourceMappingURL=AuthorityAndTokenInfo.js.map