import { Box, Heading, HStack, Image, SimpleGrid, Skeleton, Text, VStack } from "@chakra-ui/react";
import { useReserveAmount, useTokenBondingFromMint, useTokenMetadata } from "@strata-foundation/react";
import moment from "moment";
import React from "react";
import { AuthorityAndTokenInfo } from "./AuthorityAndTokenInfo";
import { BountyCardContribution } from "./BountyCardContribution";
export const BountyCard = ({ mintKey, onClick, }) => {
    const { image, displayName, loading } = useTokenMetadata(mintKey);
    const { info: tokenBonding, loading: bondingLoading } = useTokenBondingFromMint(mintKey);
    const { metadata } = useTokenMetadata(tokenBonding?.baseMint);
    const reserveAmount = useReserveAmount(tokenBonding?.publicKey);
    return (React.createElement(HStack, { w: "full", onClick: () => onClick(), align: "flex-start", spacing: 4, _hover: {
            backgroundColor: "gray.100",
            cursor: "pointer",
            textDecoration: "none",
        }, padding: 8 },
        !loading && React.createElement(Image, { w: "45px", h: "45px", src: image, alt: displayName }),
        loading && React.createElement(Skeleton, { w: "45px", h: "45px" }),
        React.createElement(SimpleGrid, { columns: [1, 2], gap: 4, w: "full" },
            React.createElement(VStack, { maxWidth: "500px", spacing: 4, align: "left" },
                !loading && displayName && (React.createElement(Heading, { fontSize: "20px", size: "md" }, displayName)),
                loading && (React.createElement(VStack, { w: "full", align: "left" },
                    React.createElement(Skeleton, { width: "full", height: "20px" }),
                    React.createElement(Skeleton, { width: "50%", height: "20px" }))),
                React.createElement(AuthorityAndTokenInfo, { mintKey: mintKey }),
                !bondingLoading && tokenBonding && (React.createElement(Text, { color: "gray.400" },
                    "Created",
                    " ",
                    moment(tokenBonding.goLiveUnixTime.toNumber() * 1000).fromNow())),
                bondingLoading && React.createElement(Skeleton, { w: "80px" })),
            React.createElement(Box, { justifySelf: [null, "flex-end"], alignSelf: "center", alignContent: "left" },
                React.createElement(BountyCardContribution, { amount: reserveAmount, symbol: metadata?.data.symbol })))));
};
//# sourceMappingURL=BountyCard.js.map