import { HStack, Spinner, StackDivider, Text, VStack } from "@chakra-ui/react";
import { useConnection } from "@solana/wallet-adapter-react";
import { Creator, roundToDecimals, useMint, useTokenAccount } from "@strata-foundation/react";
import { toNumber } from "@strata-foundation/spl-token-bonding";
import React from "react";
import { useAsync } from "react-async-hook";
import { numberWithCommas } from "../../utils/numberWithCommas";
const onCreatorClick = (c, t, tokenRef, handle) => {
    window.open(tokenRef
        ? `https://wum.bo/app/profile/view/${tokenRef.mint.toBase58()}`
        : handle
            ? `https://twitter.com/${handle}`
            : `https://explorer.solana.com/address/${c.toBase58()}`, "_blank");
};
async function getLargestTokenAccounts(connection, mint) {
    if (mint) {
        const accounts = (await connection.getTokenLargestAccounts(mint)).value;
        return accounts
            .filter((a) => a.uiAmount)
            .map((account) => ({
            publicKey: account.address,
            amount: account.uiAmount,
        }));
    }
    return [];
}
export const TopHolders = ({ mintKey }) => {
    const { connection } = useConnection();
    const { result: accounts, loading } = useAsync(getLargestTokenAccounts, [
        connection,
        mintKey,
    ]);
    if (loading) {
        return React.createElement(Spinner, null);
    }
    return (React.createElement(VStack, { w: "full", spacing: 2, divider: React.createElement(StackDivider, { borderColor: "gray.200" }) }, accounts?.map((account, index) => (React.createElement(LeaderboardItem, { rank: index + 1, key: account.publicKey.toBase58(), ...account })))));
};
const LeaderboardItem = ({ publicKey, rank, }) => {
    const { info: account, loading } = useTokenAccount(publicKey);
    const mint = useMint(account?.mint);
    if (loading || !account) {
        return React.createElement(Spinner, null);
    }
    return (React.createElement(HStack, { align: "center", w: "full", padding: 2, justify: "space-between" },
        React.createElement(HStack, { align: "center", spacing: 8 },
            React.createElement(Text, { fontWeight: 500, color: "gray.500" }, rank),
            React.createElement(Creator, { creator: account.owner, onClick: onCreatorClick })),
        React.createElement(Text, { fontWeight: 700, color: "gray.600", marginLeft: "auto" }, mint &&
            numberWithCommas(roundToDecimals(toNumber(account.amount, mint), mint.decimals)))));
};
//# sourceMappingURL=TopHolders.js.map