import React, { useState } from "react";
import { Box, Button, Flex, Input, Stack, Text, useRadioGroup, } from "@chakra-ui/react";
import { useFormContext } from "react-hook-form";
import { FormControlWithError } from "./FormControlWithError";
import { RadioCard } from "./RadioCard";
export const TokenIntervalInputs = () => {
    const { watch, formState: { errors }, register, setValue, } = useFormContext();
    const [isManualEntry, setIsManualEntry] = useState(false);
    const { getRootProps, getRadioProps } = useRadioGroup({
        name: "interval",
        onChange: (value) => setValue("interval", +value),
    });
    const interval = watch("interval");
    const group = getRootProps();
    const intervalOptions = [
        { value: 1800, heading: "30 Minutes" },
        { value: 3600, heading: "1 Hour" },
        { value: 10800, heading: "3 Hours" },
        { value: 43200, heading: "12 Hours" },
        { value: 86400, heading: "1 Day" },
        { value: 259200, heading: "3 Days" },
    ];
    return (React.createElement(React.Fragment, null,
        React.createElement(FormControlWithError, { id: "interval", label: "Interval", errors: errors, help: isManualEntry
                ? "How long should this LBC go on for (in seconds)? This period is the time during which the price will fall. We recommend you set this period long enough so that everyone gets a chance to participate. Windows less than 15 Minutes (900 seconds) are not recommended."
                : "How long should this LBC go on for? This period is the time during which the price will fall. We recommend you set this period long enough so that everyone gets a chance to participate." },
            React.createElement(Stack, { ...group, direction: "row", flexWrap: "wrap", spacing: 0 }, intervalOptions.map(({ value, heading }) => {
                const radio = getRadioProps({ value });
                return (React.createElement(RadioCard, { ...radio, isChecked: interval === value, key: value },
                    React.createElement(Flex, { w: 24, h: 10, justifyContent: "center", alignItems: "center" },
                        React.createElement(Text, { fontWeight: "bold", fontSize: "sm" }, heading))));
            })),
            React.createElement(Box, { mt: 3 },
                !isManualEntry && (React.createElement(Button, { colorScheme: "orange", variant: "link", size: "sm", onClick: () => setIsManualEntry(true) }, "Custom Interval")),
                isManualEntry && (React.createElement(React.Fragment, null,
                    React.createElement(Input, { type: "number", min: 0, step: 0.000000000001, ...register("interval") }),
                    React.createElement(Text, { color: "red.500", fontSize: "sm", mt: 2 }, "Any value less than 15 Minutes (900 seconds) will result in the initial price dropping fast.")))))));
};
//# sourceMappingURL=TokenIntervalnputs.js.map