import { Button, FormControl, FormHelperText, FormLabel, HStack, Icon, Image, Input, Text, Textarea, useRadioGroup, } from "@chakra-ui/react";
import { StorageProvider } from "@strata-foundation/spl-utils";
import React, { useEffect, useState } from "react";
import { useFormContext } from "react-hook-form";
import { RiCheckFill } from "react-icons/ri";
import { FormControlWithError } from "./FormControlWithError";
export function TokenMetadataInputs({ entityName = "post", }) {
    const { register, watch, formState: { errors }, clearErrors, setValue, setError, } = useFormContext();
    const { image } = watch();
    const [imgUrl, setImgUrl] = useState();
    const hiddenFileInput = React.useRef(null);
    const { getRootProps, getRadioProps } = useRadioGroup({
        name: "provider",
        onChange: (option) => setValue("provider", option),
    });
    const group = getRootProps();
    const storageOptions = [
        {
            value: StorageProvider.Arweave,
            heading: "Arweave",
            illustration: "/arweave.png",
            helpText: "Instant storage for your image and description, but you will need to pay a small fee in Sol for the upload",
        },
    ];
    useEffect(() => {
        if (image) {
            const reader = new FileReader();
            reader.onload = (event) => {
                setImgUrl(event.target?.result || "");
            };
            reader.readAsDataURL(image);
        }
        else {
            setImgUrl(undefined);
        }
    }, [image]);
    // Default to Arweave
    useEffect(() => {
        setValue("provider", StorageProvider.Arweave);
    }, [setValue]);
    const provider = watch("provider");
    const handleImageChange = (e) => {
        const file = e.target.files[0];
        const sizeKB = file.size / 1024;
        if (sizeKB < 25) {
            // @ts-ignore
            setError("image", {
                type: "manual",
                message: `The file ${file.name} is too small. It is ${Math.round(10 * sizeKB) / 10}KB but should be at least 25KB.`,
            });
            return;
        }
        // @ts-ignore
        setValue("image", file || null);
        // @ts-ignore
        clearErrors("image");
    };
    return (React.createElement(React.Fragment, null,
        React.createElement(FormControlWithError, { id: "name", help: `The name that will be displayed for this ${entityName}`, label: "Name", errors: errors },
            React.createElement(Input, { ...register("name") })),
        React.createElement(FormControl, { id: "image" },
            React.createElement(FormLabel, null, "Photo"),
            React.createElement(HStack, { w: "full", spacing: 4 },
                React.createElement(Button, { size: "md", colorScheme: "primary", variant: "outline", onClick: () => hiddenFileInput.current.click() }, "Choose"),
                image && (React.createElement(HStack, { spacing: 2, align: "center" },
                    React.createElement(Image, { alt: image.name, w: "32px", h: "32px", src: imgUrl }),
                    React.createElement(Text, { color: "gray.500" }, image.name),
                    React.createElement(Icon, { w: "22px", h: "22px", color: "green.400", as: RiCheckFill })))),
            React.createElement("input", { id: "image", type: "file", accept: ".png,.jpg,.gif,.mp4,.svg,.jpeg", multiple: false, onChange: handleImageChange, ref: hiddenFileInput, style: { display: "none" } }),
            React.createElement(FormHelperText, { color: errors.image?.message && "red.400" }, errors.image?.message ||
                `The image that will be displayed with this ${entityName}`)),
        React.createElement(FormControlWithError, { id: "Description", help: `The description that will be displayed for this ${entityName}`, label: "Description", errors: errors },
            React.createElement(Textarea, { borderColor: "gray.200", ...register("description") }))));
}
//# sourceMappingURL=TokenMetadataInputs.js.map