import React from "react";
import { Flex, Stack, Text, useRadioGroup } from "@chakra-ui/react";
import { useFormContext } from "react-hook-form";
import { FormControlWithError } from "./FormControlWithError";
import { RadioCard } from "./RadioCard";
export const TokenMintDecimalsInputs = ({ maxDecimals = 12, }) => {
    const { watch, formState: { errors }, setValue, clearErrors, } = useFormContext();
    const { getRootProps, getRadioProps } = useRadioGroup({
        name: "decimals",
        onChange: (value) => {
            setValue("decimals", +value);
            clearErrors("decimals");
        },
    });
    const decimals = watch("decimals");
    const group = getRootProps();
    const decimalOptions = Array.from(Array(maxDecimals + 1)).map((_, index) => ({
        value: index,
        heading: index,
    }));
    return (React.createElement(React.Fragment, null,
        React.createElement(FormControlWithError, { id: "decimals", label: "Mint Decimals", errors: errors, help: "The number of decimal places this mint will have. For example, SOL has 9 decimal places of precision. 0 is best used for 1:1 items like raffle tickets, collectibles, or something redeemable." },
            React.createElement(Stack, { ...group, direction: "row", flexWrap: "wrap", spacing: 0 }, decimalOptions.map(({ value, heading }) => {
                const radio = getRadioProps({ value });
                return (React.createElement(RadioCard, { ...radio, isChecked: decimals === value, key: value },
                    React.createElement(Flex, { w: 10, h: 10, justifyContent: "center", alignItems: "center" },
                        React.createElement(Text, { fontWeight: "bold", fontSize: "md" }, heading))));
            })))));
};
//# sourceMappingURL=TokenMintDecimalsInputs.js.map