import { Box, Collapse, Switch, Text } from "@chakra-ui/react";
import { useMetaplexTokenMetadata, usePublicKey, } from "@strata-foundation/react";
import { useRouter } from "next/router";
import React, { useEffect } from "react";
import { useFormContext } from "react-hook-form";
import { FormControlWithError } from "./FormControlWithError";
import { MintSelect } from "./MintSelect";
export function UseExistingMintInputs() {
    const { register, watch, formState: { errors }, setValue, } = useFormContext();
    const router = useRouter();
    const mint = router.query["mint"];
    const { useExistingMint, existingMint, name, symbol } = watch();
    const existingMintPkey = usePublicKey(existingMint);
    const { metadata } = useMetaplexTokenMetadata(existingMintPkey);
    useEffect(() => {
        if (mint) {
            setValue("existingMint", mint);
            setValue("useExistingMint", !!mint);
        }
    }, [mint, router, setValue]);
    useEffect(() => {
        setValue("name", metadata?.data.name);
        setValue("symbol", metadata?.data.symbol);
        setValue("uri", metadata?.data.uri);
    }, [setValue, metadata]);
    return (React.createElement(React.Fragment, null,
        React.createElement(FormControlWithError, { id: "useExistingMint", help: "Sell a set amount of an existing spl token rather than creating a new one to sell. Note that you must have the amount you wish to sell in your wallet.", label: "Use an existing token?", errors: errors },
            React.createElement(Switch, { isChecked: useExistingMint, ...register("useExistingMint") })),
        React.createElement(Box, { w: "full", p: 0 },
            React.createElement(Collapse, { in: useExistingMint, animateOpacity: true, style: { overflow: "visible" } },
                React.createElement(FormControlWithError, { id: "existingMint", help: "The mint id of the existing token to use for this sale", label: "Mint", errors: errors },
                    name && (React.createElement(Text, { color: "gray.400", size: "sm" },
                        name,
                        " (",
                        symbol,
                        ")")),
                    React.createElement(MintSelect, { value: watch("existingMint") || "", onChange: (s) => setValue("existingMint", s) }))))));
}
//# sourceMappingURL=UseExistingMintInputs.js.map