import { Box, Center, HStack, Icon, Progress, Spinner, Stack, Text, Tooltip, useColorModeValue, useDisclosure, VStack, } from "@chakra-ui/react";
import { useCapInfo, useCurve, useSolanaUnixTime, useTokenSwapFromId, useMetaplexTokenMetadata, } from "@strata-foundation/react";
import React, { useEffect, useState } from "react";
import { buildStyles, CircularProgressbar } from "react-circular-progressbar";
import { useLivePrice } from "../..//hooks/useLivePrice";
import { numberWithCommas } from "../../utils/numberWithCommas";
import { RiInformationFill } from "react-icons/ri";
import ReactCountdown from "react-countdown";
export const BlackBox = ({ children, ...other }) => {
    return (React.createElement(Box, { p: 4, rounded: "lg", backgroundColor: useColorModeValue("gray.200", "black.500"), ...other }, children));
};
export const BigText = ({ children, ...other }) => {
    return (React.createElement(Text, { fontWeight: "semibold", fontSize: "xl", ...other }, children));
};
export const LbcInfo = ({ id, useTokenOfferingCurve = false, price: inputPrice, }) => {
    const { isOpen, onToggle } = useDisclosure({
        defaultIsOpen: false,
    });
    const { tokenBonding, numRemaining, loading: loadingBonding, } = useTokenSwapFromId(id);
    const { price, loading: loadingPricing } = useLivePrice(tokenBonding?.publicKey);
    const { mintCap } = useCapInfo(tokenBonding?.publicKey, useTokenOfferingCurve);
    const priceToUse = inputPrice || price;
    const { info: curve } = useCurve(tokenBonding?.curve);
    const maxTime = 
    // @ts-ignore
    curve?.definition.timeV0.curves[0].curve.timeDecayExponentialCurveV0
        .interval;
    const unixTime = useSolanaUnixTime();
    const [elapsedTime, setElapsedTime] = useState();
    useEffect(() => {
        setElapsedTime(tokenBonding
            ? (unixTime || new Date().valueOf() / 1000) -
                tokenBonding.goLiveUnixTime.toNumber()
            : undefined);
    }, [unixTime]);
    const endDate = new Date(0);
    endDate.setUTCSeconds((tokenBonding?.goLiveUnixTime.toNumber() || 0) + (maxTime || 0));
    const isLive = tokenBonding && unixTime
        ? tokenBonding.goLiveUnixTime.toNumber() < unixTime
        : false;
    const { metadata } = useMetaplexTokenMetadata(tokenBonding?.baseMint);
    const { metadata: targetMeta } = useMetaplexTokenMetadata(tokenBonding?.targetMint);
    const renderer = ({ days, hours, minutes, seconds, completed, }) => {
        if (completed) {
            return React.createElement(BigText, null, "Finished");
        }
        return (React.createElement(BigText, null,
            days ? `${days} Days, ` : "",
            `${hours}`.padStart(2, "0"),
            ":",
            `${minutes}`.padStart(2, "0"),
            ":",
            `${seconds}`.padStart(2, "0")));
    };
    return (React.createElement(VStack, { spacing: 4, align: "stretch", justify: "stretch" },
        React.createElement(VStack, { align: "stretch", justify: "stretch" },
            React.createElement(BlackBox, { w: "full" },
                React.createElement(VStack, { align: "left", spacing: 0 },
                    React.createElement(HStack, { spacing: 1, position: "relative" },
                        React.createElement(Text, { fontSize: "sm" }, "Time Remaining"),
                        React.createElement(Box, { w: "14px", h: "14px" },
                            React.createElement(CircularProgressbar, { counterClockwise: true, value: elapsedTime && maxTime
                                    ? ((maxTime - elapsedTime) / maxTime) * 100
                                    : 0, strokeWidth: 50, styles: buildStyles({
                                    strokeLinecap: "butt",
                                    trailColor: "transparent",
                                    pathColor: "rgba(255, 255, 255, 0.36)",
                                }) }))),
                    isLive ? (
                    // @ts-ignore
                    React.createElement(ReactCountdown, { date: endDate, now: () => (unixTime ? unixTime * 1000 : new Date().valueOf()), renderer: renderer })) : (React.createElement(BigText, null, "Not Started")))),
            React.createElement(Stack, { direction: ["column", "row"], justify: "stretch" },
                React.createElement(BlackBox, { w: "full", position: "relative" },
                    React.createElement(VStack, { align: "left", spacing: 0 },
                        React.createElement(HStack, { spacing: 2 },
                            React.createElement(Text, { fontSize: "sm" }, "Price"),
                            React.createElement(Tooltip, { hasArrow: true, label: "Dynamic Pricing is similiar to a Dutch Auction. The price starts\n              high, lowers gradually, and only increases when people buy. This\n              price discovery mechanism is powered by a Strata Liquidity\n              Bootstrapping Curve (LBC)" },
                                React.createElement(Center, null,
                                    React.createElement(Icon, { w: 4, h: 4, as: RiInformationFill })))),
                        loadingPricing || typeof priceToUse == "undefined" ? (React.createElement(Spinner, { size: "lg" })) : (React.createElement(BigText, null, isNaN(priceToUse)
                            ? "Not Started"
                            : metadata?.data.symbol === "USDC"
                                ? `$${numberWithCommas(priceToUse, 2)}`
                                : `${numberWithCommas(priceToUse, 4)} ${metadata?.data.symbol}`)))),
                React.createElement(BlackBox, { w: "full", position: "relative" },
                    React.createElement(VStack, { spacing: 0, align: "left" },
                        React.createElement(Text, { fontSize: "sm" }, "Remaining"),
                        loadingBonding ? (React.createElement(Spinner, null)) : (React.createElement(BigText, null,
                            numRemaining ? numberWithCommas(numRemaining, 4) : "0",
                            " ",
                            targetMeta?.data.symbol)),
                        React.createElement(Progress, { w: "88%", size: "xs", h: "2px", position: "absolute", bottom: "8px", colorScheme: "primary", background: "rgba(196, 196, 196, 0.4)", value: ((numRemaining || 0) / (mintCap || 0)) * 100 })))))));
};
//# sourceMappingURL=LbcInfo.js.map