import React from "react";
import { VStack, HStack, Text, Tbody, useDisclosure, TableContainer, Table, Thead, Tr, Th, Spinner, Td, Center, Box, Switch, Button, IconButton, useColorModeValue, Icon, } from "@chakra-ui/react";
import { useTransactions } from "../../hooks/useTransactions";
import { useMint, useTokenBonding, useTokenBondingKey, } from "@strata-foundation/react";
import { useMemo } from "react";
import moment from "moment";
import { numberWithCommas } from "../../utils/numberWithCommas";
import { useWallet } from "@solana/wallet-adapter-react";
import { BiRefresh } from "react-icons/bi";
export const TransactionHistory = ({ tokenBondingKey, }) => {
    const { info: tokenBonding, loading: loadingBonding } = useTokenBonding(tokenBondingKey);
    const { isOpen: mineOnly, onToggle } = useDisclosure();
    const { result: sellOnlyTokenBondingKey, error: keyError1 } = useTokenBondingKey(tokenBonding?.targetMint, 1);
    if (keyError1) {
        console.error(keyError1);
    }
    const { info: sellOnlyTokenBonding, loading: sellOnlyLoading } = useTokenBonding(sellOnlyTokenBondingKey);
    const { publicKey } = useWallet();
    const address = useMemo(() => (mineOnly ? publicKey || undefined : tokenBondingKey), [publicKey, tokenBondingKey, mineOnly]);
    const { transactions, fetchMore, loadingInitial, fetchNew, loadingMore } = useTransactions({
        numTransactions: 5,
        address,
    });
    const baseMint = useMint(tokenBonding?.baseMint);
    const targetMint = useMint(tokenBonding?.targetMint);
    const data = useMemo(() => {
        return tokenBonding && !sellOnlyLoading
            ? transactions
                .map((transaction) => {
                const reserveIdx = transaction.transaction.message.accountKeys
                    .map((k) => k.toBase58())
                    .indexOf(tokenBonding.baseStorage.toBase58());
                const sellOnlyReserveIdx = transaction.transaction.message.accountKeys
                    .map((k) => k.toBase58())
                    .indexOf(sellOnlyTokenBonding?.baseStorage.toBase58() || "");
                const preReserves = transaction.meta?.preTokenBalances?.find((b) => b.accountIndex == reserveIdx &&
                    b.mint == tokenBonding.baseMint.toBase58())?.uiTokenAmount.uiAmount;
                const postReserves = transaction.meta?.postTokenBalances?.find((b) => b.accountIndex == reserveIdx &&
                    b.mint == tokenBonding.baseMint.toBase58())?.uiTokenAmount.uiAmount;
                const reserveChange = (postReserves || 0) - (preReserves || 0);
                const preToken = transaction.meta?.preTokenBalances
                    ?.filter((b) => b.mint == tokenBonding.targetMint.toBase58())
                    ?.map((v) => v.uiTokenAmount.uiAmount)
                    ?.reduce((v1, v2) => (v1 || 0) + (v2 || 0), 0);
                const postToken = transaction.meta?.postTokenBalances
                    ?.filter((b) => b.mint == tokenBonding.targetMint.toBase58())
                    ?.map((v) => v.uiTokenAmount.uiAmount)
                    ?.reduce((v1, v2) => (v1 || 0) + (v2 || 0), 0);
                const tokenChange = (postToken || 0) - (preToken || 0);
                const preSellOnlyReserves = transaction.meta?.preTokenBalances?.find((b) => b.accountIndex == sellOnlyReserveIdx &&
                    b.mint == sellOnlyTokenBonding?.baseMint.toBase58())?.uiTokenAmount.uiAmount;
                const postSellOnlyReserves = transaction.meta?.postTokenBalances?.find((b) => b.accountIndex == sellOnlyReserveIdx &&
                    b.mint == sellOnlyTokenBonding?.baseMint.toBase58())?.uiTokenAmount.uiAmount;
                const sellOnlyChange = (preSellOnlyReserves || 0) - (postSellOnlyReserves || 0);
                return {
                    price: reserveChange / Math.max(tokenChange, sellOnlyChange),
                    volume: Math.max(tokenChange, sellOnlyChange),
                    time: (transaction.blockTime || 0) * 1000,
                    signature: transaction.transaction.signatures[0],
                };
            })
                .filter((d) => d.price)
            : [];
    }, [transactions, tokenBonding, sellOnlyLoading, sellOnlyTokenBonding]);
    const icoColor = useColorModeValue("black", "white");
    const thProps = {
        textTransform: "none",
        color: icoColor,
        fontSize: "14px",
        letterSpacing: "none",
        padding: 4,
    };
    return (React.createElement(VStack, { spacing: 4, w: "full", align: "left" },
        React.createElement(HStack, { justify: "space-between" },
            React.createElement(Text, { fontSize: "18px", fontWeight: "700" }, "Recent Transactions"),
            React.createElement(HStack, { spacing: 1 },
                publicKey && (React.createElement(Switch, { size: "sm", onChange: () => onToggle() }, "Mine Only")),
                React.createElement(IconButton, { "aria-label": "Fetch New Transactions", title: "Fetch New Transactions", onClick: () => fetchNew(20), isLoading: loadingMore, color: icoColor, variant: "link", icon: React.createElement(Icon, { h: "24px", w: "24px", mb: "-2px", as: BiRefresh }) }))),
        React.createElement(TableContainer, null,
            React.createElement(Table, { variant: "simple" },
                React.createElement(Thead, null,
                    React.createElement(Tr, null,
                        React.createElement(Th, { ...thProps }, "Volume"),
                        React.createElement(Th, { ...thProps }, "Price"),
                        React.createElement(Th, { ...thProps }, "Time"))),
                React.createElement(Tbody, null, data.map(({ price, volume, time, signature }) => {
                    return (React.createElement(Tr, { onClick: () => window.open(`https://explorer.solana.com/tx/${signature}`, "_blank"), _hover: { background: "#303947", cursor: "pointer" }, key: signature },
                        React.createElement(Td, null, numberWithCommas(volume, targetMint?.decimals)),
                        React.createElement(Td, null, numberWithCommas(price, baseMint?.decimals)),
                        React.createElement(Td, { title: moment(time).format("llll") }, moment(time).fromNow())));
                })))),
        loadingInitial && (React.createElement(Box, { w: "100%" },
            React.createElement(Center, null,
                React.createElement(Spinner, null)))),
        React.createElement(Button, { color: "gray.500", variant: "ghost", onClick: () => fetchMore(20) }, "Show More")));
};
//# sourceMappingURL=TransactionHistory.js.map