import { Alert, Button, Center, Heading, Image, Spinner, Text, Box, Stack, AspectRatio, Skeleton, Badge, HStack, FormControl, FormLabel, Icon, Flex, } from "@chakra-ui/react";
import { useWallet } from "@solana/wallet-adapter-react";
import { Notification, useBondingPricing, useMint, useOwnedAmount, useProvider, useStrataSdks, useTokenBondingFromMint, useTokenMetadata, } from "@strata-foundation/react";
import React, { useState } from "react";
import { useAsyncCallback } from "react-async-hook";
import toast from "react-hot-toast";
import { SaleItemAdmin } from "./SaleItemAdmin";
import { FiClock } from "react-icons/fi";
import { QuantityPicker } from "./QuantityPicker";
async function buy(tokenBondingSdk, tokenBonding, quantity) {
    await tokenBondingSdk.buy({
        tokenBonding,
        desiredTargetAmount: quantity,
        slippage: 0.05,
    });
    toast.custom((t) => (React.createElement(Notification, { show: t.visible, type: "success", heading: "Transactoin Successful", message: `Successfully purchased ${quantity}`, onDismiss: () => toast.dismiss(t.id) })));
}
export const SaleItem = ({ mintKey, name, description, image, }) => {
    const { info: tokenBonding, loading: bondingLoading } = useTokenBondingFromMint(mintKey);
    const { connected, publicKey } = useWallet();
    const targetMint = useMint(tokenBonding?.targetMint);
    const { image: targetImage, metadata: targetMetadata, data: targetData, loading: targetMetaLoading, } = useTokenMetadata(tokenBonding?.targetMint);
    const { metadata: baseMetadata, loading: metadataLoading } = useTokenMetadata(tokenBonding?.baseMint);
    const { pricing, loading: pricingLoading } = useBondingPricing(tokenBonding?.publicKey);
    const { tokenBondingSdk } = useStrataSdks();
    const [qty, setQty] = useState(1);
    const { execute, loading, error } = useAsyncCallback(buy);
    const { awaitingApproval } = useProvider();
    const qtyNumber = Number(qty);
    const mintCapNumber = tokenBonding?.mintCap?.toNumber();
    const targetSupplyNumber = targetMint?.supply.toNumber();
    const balance = useOwnedAmount(tokenBonding?.baseMint);
    const price = pricing?.buyTargetAmount(1);
    const total = pricing?.buyTargetAmount(Number(qty) || 1);
    const notEnoughFunds = (balance || 0) < (total || 0);
    const passedMintCap = mintCapNumber && ((targetSupplyNumber || 0) >= (mintCapNumber || 0));
    const remainingAmount = (mintCapNumber || 0) - (targetSupplyNumber || 0);
    const isAdmin = publicKey &&
        tokenBonding?.reserveAuthority?.equals(publicKey);
    name = targetMetadata?.data.name || name;
    image = targetImage || image;
    description = targetData?.description || description;
    const dataMissing = !name && !image && !description;
    if (!targetMetaLoading && dataMissing) {
        return (React.createElement(Center, { height: "300px" },
            React.createElement(Text, null,
                React.createElement("b", null, "404: "),
                " Not found")));
    }
    if (dataMissing) {
        return React.createElement(Spinner, null);
    }
    return (React.createElement(Box, { pt: "8", px: { base: "5", lg: "8" }, pb: { base: "10", lg: "8" }, w: "full" },
        React.createElement(Stack, { direction: { base: "column", md: "row" }, spacing: "8" },
            React.createElement(Box, { flex: "1" },
                React.createElement(Stack, { spacing: "4" },
                    React.createElement(AspectRatio, { ratio: 4 / 3 },
                        React.createElement(Image, { rounded: "md", src: image, objectFit: "cover", alt: "Placeholder", fallback: React.createElement(Skeleton, null) })))),
            React.createElement(Box, { flex: "1" },
                React.createElement(Stack, { spacing: { base: "4", md: "8" } },
                    React.createElement(Stack, { spacing: { base: "2", md: "4" } },
                        React.createElement(Stack, { spacing: "3" },
                            React.createElement(Badge, { alignSelf: "start", textTransform: "none", size: "sm", fontWeight: "semibold", lineHeight: "1rem", borderRadius: "base", py: "1", px: "2", bg: "primary.500", color: "white" }, passedMintCap ? "Sold Out" : "For Sale")),
                        React.createElement(Heading, { size: "lg", fontWeight: "medium" }, name),
                        React.createElement(Stack, { direction: { base: "column", md: "row" }, spacing: "1", align: "baseline", justify: "space-between" },
                            React.createElement(HStack, { spacing: "1" },
                                React.createElement(Text, { as: "span", fontSize: "lg", fontWeight: "semibold", color: "gray.700" },
                                    baseMetadata?.data.symbol,
                                    " ",
                                    pricingLoading ? React.createElement(Spinner, { size: "xs" }) : price?.toFixed(2)))),
                        React.createElement(Text, { color: "gray.600", whiteSpace: "pre-line" }, description)),
                    React.createElement(HStack, { spacing: { base: "4", md: "8" }, align: "flex-end", justify: "space-evenly" },
                        mintCapNumber && (React.createElement(Box, { flex: "1" },
                            React.createElement(FormControl, null,
                                React.createElement(FormLabel, { fontSize: "sm", fontWeight: "medium" },
                                    React.createElement(HStack, { spacing: "2" },
                                        React.createElement(Text, null, "Available"),
                                        mintCapNumber && remainingAmount < mintCapNumber / 4 && (React.createElement(HStack, { spacing: "1" },
                                            React.createElement(Icon, { as: FiClock }),
                                            React.createElement(Text, { fontSize: "xs", fontWeight: "medium" }, "Low stock"))))),
                                React.createElement(Flex, { borderRadius: "base", px: "2", py: "0.705rem", borderWidth: "1px", justifyContent: "space-between" },
                                    React.createElement(Center, { minW: "8" },
                                        React.createElement(Text, { as: "span", fontWeight: "semibold", userSelect: "none" }, bondingLoading ? (React.createElement(Spinner, { size: "xs" })) : (React.createElement("span", null,
                                            remainingAmount,
                                            " / ",
                                            mintCapNumber || 0)))))))),
                        React.createElement(Box, { flex: "1" },
                            React.createElement(QuantityPicker, { defaultValue: 1, max: remainingAmount > 0
                                    ? Math.round(remainingAmount / 2)
                                    : mintCapNumber
                                        ? 0
                                        : Infinity, onChange: (num) => setQty(num) }))),
                    React.createElement(Stack, { spacing: "3" },
                        error && (React.createElement(Alert, { status: "error" },
                            React.createElement(Alert, { status: "error" }, error.toString()))),
                        React.createElement(Button, { isDisabled: !connected ||
                                notEnoughFunds ||
                                passedMintCap ||
                                !qtyNumber ||
                                qtyNumber <= 0, isLoading: loading, value: qty, loadingText: awaitingApproval ? "Awaiting Approval" : "Loading", onClick: () => qtyNumber &&
                                qtyNumber > 0 &&
                                execute(tokenBondingSdk, tokenBonding?.publicKey, qtyNumber), w: "full", size: "lg", colorScheme: "primary" }, !connected
                            ? "Connect a Wallet"
                            : notEnoughFunds
                                ? `Not Enough ${baseMetadata?.data.symbol || "funds"}`
                                : passedMintCap
                                    ? "Sold Out"
                                    : "Buy"),
                        isAdmin && tokenBonding && (React.createElement(SaleItemAdmin, { tokenBondingKey: tokenBonding.publicKey })),
                        React.createElement(Center, null,
                            React.createElement(Text, null,
                                "Total: ",
                                baseMetadata?.data.symbol,
                                " ",
                                pricingLoading ? React.createElement(Spinner, { size: "xs" }) : total,
                                " "))))))));
};
//# sourceMappingURL=SaleItem.js.map