import { MarketplaceSdk } from "@strata-foundation/marketplace-sdk";
import { useProvider } from "@strata-foundation/react";
import React, { useContext, useMemo } from "react";
import { useAsync } from "react-async-hook";
export const MarketplaceSdkContext = React.createContext({
    loading: true,
});
async function tryProm(prom) {
    try {
        return await prom;
    }
    catch (e) {
        console.error(e);
    }
    return undefined;
}
async function getSdk(provider) {
    if (!provider) {
        console.warn("No provider passed via ProviderContext to StrataSdkContext. Please provide a provider");
        return undefined;
    }
    return tryProm(MarketplaceSdk.init(provider));
}
export const MarketplaceSdkProviderRaw = ({ children }) => {
    const { provider } = useProvider();
    const { result, loading, error } = useAsync(getSdk, [provider]);
    const sdks = useMemo(() => ({
        marketplaceSdk: result,
        error,
        loading,
    }), [result, loading, error]);
    return (React.createElement(MarketplaceSdkContext.Provider, { value: sdks }, children));
};
export const MarketplaceSdkProvider = ({ children }) => {
    return (React.createElement(MarketplaceSdkProviderRaw, null, children));
};
export const useMarketplaceSdk = () => {
    return useContext(MarketplaceSdkContext);
};
//# sourceMappingURL=marketplaceSdkContext.js.map