import { useGovernance, useTokenBonding, useTokenMetadata, useTokenRef } from "@strata-foundation/react";
export function useIsBountyAdmin(wallet, tokenBondingKey) {
    const { info: tokenBonding, loading: bondingLoading } = useTokenBonding(tokenBondingKey);
    const { info: governance, loading: governanceLoading } = useGovernance(tokenBonding?.reserveAuthority);
    const { metadata: targetMetadata, loading: targetMetaLoading, } = useTokenMetadata(tokenBonding?.targetMint);
    const { info: tokenRef, loading: tokenRefLoading } = useTokenRef(tokenBonding?.reserveAuthority);
    // Was an unclaimed social token that was the authority over this
    const isTokenRefAuthority = tokenRef && wallet && tokenRef.authority?.equals(wallet);
    return {
        loading: targetMetaLoading ||
            bondingLoading ||
            governanceLoading ||
            tokenRefLoading,
        isAdmin: Boolean((wallet &&
            tokenBonding?.reserveAuthority?.equals(wallet)) ||
            governance ||
            isTokenRefAuthority),
        isEditor: Boolean(targetMetadata?.updateAuthority &&
            targetMetadata.updateAuthority == wallet?.toBase58()),
    };
}
//# sourceMappingURL=useIsBountyAdmin.js.map